@@ -166,3 +166,45 @@ def test_upload(authed_client: Client):
     with open(fpath, "rb") as f:
         uploaded = authed_client.upload(f)
     assert uploaded
+
+
+@pytest.mark.vcr
+def test_delete(authed_client: Client):
+    activity_id = "12135235656"
+    path = f"/activity-service/activity/{activity_id}"
+    assert authed_client.connectapi(path)
+    authed_client.delete(
+        "connectapi",
+        path,
+        api=True,
+    )
+    with pytest.raises(GarthHTTPError) as e:
+        authed_client.connectapi(path)
+    assert "404" in str(e.value)
+
+
+@pytest.mark.vcr
+def test_put(authed_client: Client):
+    data = [
+        {
+            "changeState": "CHANGED",
+            "trainingMethod": "HR_RESERVE",
+            "lactateThresholdHeartRateUsed": 170,
+            "maxHeartRateUsed": 185,
+            "restingHrAutoUpdateUsed": False,
+            "sport": "DEFAULT",
+            "zone1Floor": 130,
+            "zone2Floor": 140,
+            "zone3Floor": 150,
+            "zone4Floor": 160,
+            "zone5Floor": 170,
+        }
+    ]
+    path = "/biometric-service/heartRateZones"
+    authed_client.put(
+        "connectapi",
+        path,
+        api=True,
+        json=data,
+    )
+    assert authed_client.connectapi(path)
